==> calendar-v1.7.20.zip: calendar/messages/fr/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Ajouter</strong> un calendrier à votre profil',
    '<strong>Choose</strong> target calendar' => '<strong>Choisir</strong> le calendrier de destination',
    '<strong>Reminder</strong> settings' => 'Rappel',
    'Add all Space members with status {status}' => 'Ajouter tous les membres de l’Espace avec le statut {status}',
    'Add participants...' => 'Ajouter des participant·es…',
    'Added: {users}' => 'Ajoutés : {users}',
    'Additional Information for participants' => 'Informations supplémentaires pour les participant·es',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Ce module permet d\'ajouter un calendrier pour les événements privés ou publics à votre profil et au menu principal.',
    'Adds an event calendar to this space.' => 'Ce module permet d\'ajouter un calendrier à cet espace.',
    'After (occurrences)' => 'Après (nombre d\'occurrences)',
    'All Day' => 'Toute la journée',
    'Allow option \'Decline\'' => 'Autoriser le choix « Refuser »',
    'Allow option \'Undecided\'' => 'Autoriser le choix « Je ne sais pas encore »',
    'Allows the user to create new calendar entries' => 'Autoriser l\'utilisateur à créer de nouvelles entrées dans le calendrier',
    'Allows the user to edit/delete existing calendar entries' => 'Autoriser l\'utilisateur à modifier/supprimer des entrées existantes dans le calendrier',
    'Attending' => 'Participe',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => 'Avant de pouvoir sélectionner un calendrier cible, le module doit être activé dans au moins un espace.',
    'Birthday' => 'Anniversaire',
    'CalDAV' => 'CalDAV',
    'Calendar' => 'Calendrier',
    'Calendar event' => 'Événement du calendrier',
    'Calendar event content ID' => 'ID de contenu de l’évènement de calendrier',
    'Calendar events' => 'Événements du calendrier',
    'Cancel Event' => 'Annuler l\'événement',
    'Cannot remove the participant!' => 'Impossible de retirer le ou la participant·e !',
    'Create entry' => 'Créer une entrée',
    'Custom reminder' => 'Rappels personnalisés',
    'Day' => 'Jour',
    'Days' => 'Jours',
    'Default reminder settings' => 'Rappels par défaut',
    'Delete all events' => 'Supprimer toutes les occurrences',
    'Deleted' => 'Supprimé',
    'Description' => 'Description',
    'Display events within the next X days' => 'Afficher les événements des X prochains jours',
    'Do you want to install this module on your profile?' => 'Voulez-vous installer ce module sur votre profil ?',
    'Download ICS' => 'Télécharger au format ICS',
    'Edit' => 'Modifier',
    'Edit Event' => 'Modifier l’événement',
    'Edit all events' => 'Éditer toutes les occurrences',
    'Edit this and following events' => 'Éditer cette occurrences et les suivantes',
    'Edit this event' => 'Modifier cet événement',
    'Email' => 'E-mail',
    'Enable' => 'Activer',
    'Enable Reminder' => 'Activer un rappel',
    'End' => 'Fin',
    'End Date' => 'Date de fin',
    'End Time' => 'Heure de fin',
    'End time must be after start time!' => 'L\'heure de fin doit être après l\'heure de début !',
    'Event' => 'Événement',
    'Event Type' => 'Type d\'événement',
    'Event Types' => 'Types d’événements',
    'Event could not be deleted!' => 'L’événement n’a pas pu être supprimé !',
    'Event has been be deleted!' => 'L’événement a été supprimé !',
    'Event not found!' => 'Événement introuvable !',
    'Export as {type}' => 'Exporter comme {type}',
    'Files' => 'Fichiers',
    'Filter by types' => 'Filtrer selon les types',
    'Friday' => 'Vendredi',
    'From Newest to Oldest' => 'Du plus récent au plus ancien',
    'From Oldest to Newest' => 'Du plus ancien au plus récent',
    'Here you can configure default settings for all calendar events.' => 'Ici vous pouvez configurer les rappels par défaut pour tous les évènements.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Ici vous pouvez configurer les rappels par défaut.  Ces paramètres peuvent-être outrepassés par les réglages des espaces ou des profils.',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
        <strong>Set reminder</strong> link.' => 'Ici vous pouvez configurer les rappels par défaut pour cet évènement. Les utilisateurs peuvent outrepasser ces réglages avec le lien <strong>Régler les rappels</strong>.',
    'Hour' => 'Heure',
    'I\'m attending' => 'Je participe',
    'ID' => 'ID',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'Pour ajouter des événements à votre profil, vous devez d\'abord activer le module calendrier.',
    'Include Organizer and Participant Info in Exports' => 'Inclure dans les exportations les infos sur l’organisateur ou l’organisatrice et sur les participant·es.',
    'Interested' => 'Intéressé',
    'Invalid date or time format!' => 'Format de date ou d\'heure invalide !',
    'Invalid day of month given' => 'Jour du mois entré incorrect',
    'Invalid event type id selected.' => 'L\'ID du type d’événement sélectionné est invalide.',
    'Invalid frequency given' => 'Fréquence entrée incorrecte',
    'Invalid interval given' => 'Intervalle entré incorrect',
    'Invalid week day selection' => 'Sélection des jours de la semaine invalide',
    'Invite' => 'Inviter',
    'Invited: {users}' => 'Invité·es : {users}',
    'JWT Key' => 'Clé JWT',
    'JWT Token Expiration' => 'Délai d’expiration du jeton JWT',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => 'Laissez vide pour faire la liste de tous les événements. Saisissez 0 pour afficher uniquement les événements d’aujourd\'hui.',
    'List' => 'Liste',
    'Location' => 'Lieu',
    'Manage entries' => 'Gérer les entrées',
    'Maximum number of participants' => 'Nombre maximum de participants',
    'Minute' => 'Minute',
    'Mode' => 'Mode',
    'Monday' => 'Lundi',
    'Month' => 'Mois',
    'Monthly on day {dayOfMonth}' => 'Tous les mois, le {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Le {position} {dayOfWeek} de chaque mois',
    'Months' => 'Mois',
    'Never' => 'Jamais',
    'Next' => 'Suivant',
    'No new participants were added.' => 'Aucun·e participant·e n’a été ajouté·e.',
    'No new participants were invited.' => 'Aucun·e participant·e n’a été invité·e.',
    'No reminder' => 'Pas de rappel',
    'Notify participants about changes' => 'Notifier les participant·es des modifications',
    'On date' => 'Un jour précis',
    'Participant removed.' => 'Participant·e supprimé·e',
    'Participants' => 'Participant·es',
    'Participation Status' => 'Participation',
    'Please select new participants.' => 'Veuillez sélectionner de nouveaux ou nouvelles participant·es.',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => 'Les événements privés sont uniquement visibles par vous et vos amis (si le système d’amitié est activé).',
    'Profile Calendar' => 'Calendrier du profil',
    'Public' => 'Public',
    'Recurring' => 'Récurrence',
    'Reopen Event' => 'Reprendre l’événement',
    'Repeat every' => 'Répéter tous les',
    'Saturday' => 'Samedi',
    'Select calendar...' => 'Sélectionnez un calendrier...',
    'Select space...' => 'Sélectionnez un espace...',
    'Set reminder' => 'Régler un rappel',
    'Show past events' => 'Afficher les événements passés',
    'Sorting' => 'Tri',
    'Start Date' => 'Date de début',
    'Start Time' => 'Heure de début',
    'Status cannot be updated.' => 'Le statut ne peut être mis à jour.',
    'Status updated.' => 'Statut mis à jour.',
    'Sunday' => 'Dimanche',
    'The event has already ended.' => 'L’événement est déjà terminé.',
    'This event does not support recurrent events' => 'Cet évènement ne peut être répété',
    'Thursday' => 'Jeudi',
    'Time Zone' => 'Fuseau horaire',
    'Title' => 'Titre',
    'Today' => 'Aujourd’hui',
    'Tuesday' => 'Mardi',
    'Upcoming {type}' => 'À venir {type}',
    'Upcoming {type}: {title}' => 'À venir {type} : {title}',
    'Use default reminder' => 'Utiliser les rappels par défaut',
    'User birthdays' => 'Anniversaires des utilisateurs et utilisatrices',
    'Wednesday' => 'Mercredi',
    'Week' => 'Semaine',
    'Weeks' => 'Semaines',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => 'Lorsque cette option est activée, les exportations du calendrier (ics, iCal, CalDAV) incluent le nom et l’adresse électronique de l’organisateur ou organisatrice et des participants. Désactivez-la pour améliorer la protection de la vie privée.',
    'Year' => 'Année',
    'Years' => 'Années',
    'You cannot invite participants!' => 'Vous ne pouvez pas inviter de participant·es !',
    'You don\'t have permission to delete this event!' => 'Vous n\'avez pas les permissions pour effacer cet événement.',
    'You have an <strong>{type}</strong> coming up' => 'Un événement de type <strong>{type}</strong> arrive bientôt',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Un événement de type <strong>{type}</strong> arrive bientôt : {title}',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => 'Vous êtes inscrit·e à l’événement « {contentTitle} » dans l’espace {spaceName} commençant à {time}.',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => 'Vous êtes inscrit·e à l’événement « {contentTitle} » commençant à {time}.',
    'You have been registered for the event "{contentTitle}".' => 'Vous êtes inscrit·e à l’événement « {contentTitle} ».',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Vos paramètres de rappels pour l\'évènement : <strong>\'{title}\'</strong>',
    'canceled' => 'annulé',
    'disabled' => 'désactivé',
    'first' => 'premier',
    'forth' => 'quatrième',
    'global' => 'global',
    'iCal' => 'iCal',
    'in seconds. 0 for no JWT token expiration.' => 'en secondes. 0 pour aucun délai d’expiration du jeton JWT.',
    'last' => 'dernier',
    'on weekdays' => 'les',
    'second' => 'deuxième',
    'third' => 'troisième',
    '{displayName} Birthday' => 'Anniversaire de {displayName}',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} vous a ajouté à l\'événement « {contentTitle} » dans l\'espace {spaceName} et qui débute à {time}.',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} vient de vous ajouter à l’événement « {contentTitle} ».',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} vient de vous inviter à l’événement « {contentTitle} » dans l’espace {spaceName} ; l’événement commence à {time}.',
    '{displayName} invited you to the event "{contentTitle}".' => '{displayName} vient de vous inviter à l’événement « {contentTitle} ».',
    '{name} Calendar' => 'Calendrier {name}',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
];

==> calendar-v1.8.3.zip: calendar/messages/fr/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Ajouter</strong> un calendrier à votre profil',
    '<strong>Choose</strong> target calendar' => '<strong>Choisir</strong> le calendrier de destination',
    '<strong>Reminder</strong> settings' => 'Rappel',
    'Add all Space members with status {status}' => 'Ajouter tous les membres de l’Espace avec le statut {status}',
    'Add participants...' => 'Ajouter des participant·es…',
    'Added: {users}' => 'Ajoutés : {users}',
    'Additional Information for participants' => 'Informations supplémentaires pour les participant·es',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Ce module permet d\'ajouter un calendrier pour les événements privés ou publics à votre profil et au menu principal.',
    'Adds an event calendar to this space.' => 'Ce module permet d\'ajouter un calendrier à cet espace.',
    'After (occurrences)' => 'Après (nombre d\'occurrences)',
    'All Day' => 'Toute la journée',
    'Allow option \'Decline\'' => 'Autoriser le choix « Refuser »',
    'Allow option \'Undecided\'' => 'Autoriser le choix « Je ne sais pas encore »',
    'Allows the user to create new calendar entries' => 'Autoriser l\'utilisateur à créer de nouvelles entrées dans le calendrier',
    'Allows the user to edit/delete existing calendar entries' => 'Autoriser l\'utilisateur à modifier/supprimer des entrées existantes dans le calendrier',
    'Attending' => 'Participe',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => 'Avant de pouvoir sélectionner un calendrier cible, le module doit être activé dans au moins un espace.',
    'Birthday' => 'Anniversaire',
    'CalDAV' => 'CalDAV',
    'Calendar' => 'Calendrier',
    'Calendar event' => 'Événement du calendrier',
    'Calendar event content ID' => 'ID de contenu de l’évènement de calendrier',
    'Calendar events' => 'Événements du calendrier',
    'Cancel Event' => 'Annuler l\'événement',
    'Cannot remove the participant!' => 'Impossible de retirer le ou la participant·e !',
    'Create entry' => 'Créer une entrée',
    'Custom reminder' => 'Rappels personnalisés',
    'Day' => 'Jour',
    'Days' => 'Jours',
    'Default reminder settings' => 'Rappels par défaut',
    'Delete all events' => 'Supprimer toutes les occurrences',
    'Deleted' => 'Supprimé',
    'Description' => 'Description',
    'Display events within the next X days' => 'Afficher les événements des X prochains jours',
    'Do you want to install this module on your profile?' => 'Voulez-vous installer ce module sur votre profil ?',
    'Download ICS' => 'Télécharger au format ICS',
    'Edit' => 'Modifier',
    'Edit Event' => 'Modifier l’événement',
    'Edit all events' => 'Éditer toutes les occurrences',
    'Edit this and following events' => 'Éditer cette occurrences et les suivantes',
    'Edit this event' => 'Modifier cet événement',
    'Email' => 'E-mail',
    'Enable' => 'Activer',
    'Enable Reminder' => 'Activer un rappel',
    'End' => 'Fin',
    'End Date' => 'Date de fin',
    'End Time' => 'Heure de fin',
    'End time must be after start time!' => 'L\'heure de fin doit être après l\'heure de début !',
    'Event' => 'Événement',
    'Event Type' => 'Type d\'événement',
    'Event Types' => 'Types d’événements',
    'Event could not be deleted!' => 'L’événement n’a pas pu être supprimé !',
    'Event has been be deleted!' => 'L’événement a été supprimé !',
    'Event not found!' => 'Événement introuvable !',
    'Export as {type}' => 'Exporter comme {type}',
    'Files' => 'Fichiers',
    'Filter by types' => 'Filtrer selon les types',
    'Friday' => 'Vendredi',
    'From Newest to Oldest' => 'Du plus récent au plus ancien',
    'From Oldest to Newest' => 'Du plus ancien au plus récent',
    'Here you can configure default settings for all calendar events.' => 'Ici vous pouvez configurer les rappels par défaut pour tous les évènements.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Ici vous pouvez configurer les rappels par défaut.  Ces paramètres peuvent-être outrepassés par les réglages des espaces ou des profils.',
    'Hour' => 'Heure',
    'I\'m attending' => 'Je participe',
    'ID' => 'ID',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'Pour ajouter des événements à votre profil, vous devez d\'abord activer le module calendrier.',
    'Include Organizer and Participant Info in Exports' => 'Inclure dans les exportations les infos sur l’organisateur ou l’organisatrice et sur les participant·es.',
    'Interested' => 'Intéressé',
    'Invalid date or time format!' => 'Format de date ou d\'heure invalide !',
    'Invalid day of month given' => 'Jour du mois entré incorrect',
    'Invalid event type id selected.' => 'L\'ID du type d’événement sélectionné est invalide.',
    'Invalid frequency given' => 'Fréquence entrée incorrecte',
    'Invalid interval given' => 'Intervalle entré incorrect',
    'Invalid week day selection' => 'Sélection des jours de la semaine invalide',
    'Invite' => 'Inviter',
    'Invited: {users}' => 'Invité·es : {users}',
    'JWT Key' => 'Clé JWT',
    'JWT Token Expiration' => 'Délai d’expiration du jeton JWT',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => 'Laissez vide pour faire la liste de tous les événements. Saisissez 0 pour afficher uniquement les événements d’aujourd\'hui.',
    'List' => 'Liste',
    'Location' => 'Lieu',
    'Manage entries' => 'Gérer les entrées',
    'Maximum number of participants' => 'Nombre maximum de participants',
    'Minute' => 'Minute',
    'Mode' => 'Mode',
    'Monday' => 'Lundi',
    'Month' => 'Mois',
    'Monthly on day {dayOfMonth}' => 'Tous les mois, le {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Le {position} {dayOfWeek} de chaque mois',
    'Months' => 'Mois',
    'Never' => 'Jamais',
    'Next' => 'Suivant',
    'No new participants were added.' => 'Aucun·e participant·e n’a été ajouté·e.',
    'No new participants were invited.' => 'Aucun·e participant·e n’a été invité·e.',
    'No reminder' => 'Pas de rappel',
    'Notify participants about changes' => 'Notifier les participant·es des modifications',
    'On date' => 'Un jour précis',
    'Participant removed.' => 'Participant·e supprimé·e',
    'Participants' => 'Participant·es',
    'Participation Status' => 'Participation',
    'Please select new participants.' => 'Veuillez sélectionner de nouveaux ou nouvelles participant·es.',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => 'Les événements privés sont uniquement visibles par vous et vos amis (si le système d’amitié est activé).',
    'Profile Calendar' => 'Calendrier du profil',
    'Public' => 'Public',
    'Recurring' => 'Récurrence',
    'Reopen Event' => 'Reprendre l’événement',
    'Repeat every' => 'Répéter tous les',
    'Saturday' => 'Samedi',
    'Select calendar...' => 'Sélectionnez un calendrier...',
    'Select space...' => 'Sélectionnez un espace...',
    'Set reminder' => 'Régler un rappel',
    'Show past events' => 'Afficher les événements passés',
    'Sorting' => 'Tri',
    'Start Date' => 'Date de début',
    'Start Time' => 'Heure de début',
    'Status cannot be updated.' => 'Le statut ne peut être mis à jour.',
    'Status updated.' => 'Statut mis à jour.',
    'Sunday' => 'Dimanche',
    'The event has already ended.' => 'L’événement est déjà terminé.',
    'This event does not support recurrent events' => 'Cet évènement ne peut être répété',
    'Thursday' => 'Jeudi',
    'Time Zone' => 'Fuseau horaire',
    'Title' => 'Titre',
    'Today' => 'Aujourd’hui',
    'Tuesday' => 'Mardi',
    'Upcoming {type}' => 'À venir {type}',
    'Upcoming {type}: {title}' => 'À venir {type} : {title}',
    'Use default reminder' => 'Utiliser les rappels par défaut',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => 'Utilisé pour la génération sécurisée des URL de flux iCal et l\'authentification CalDAV. La modification de cette clé révoquera toutes les URL iCal et connexions CalDAV existantes. Si cette clé est vide, une clé aléatoire est générée automatiquement.',
    'User birthdays' => 'Anniversaires des utilisateurs et utilisatrices',
    'Wednesday' => 'Mercredi',
    'Week' => 'Semaine',
    'Weeks' => 'Semaines',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => 'Lorsque cette option est activée, les exportations du calendrier (ics, iCal, CalDAV) incluent le nom et l’adresse électronique de l’organisateur ou organisatrice et des participants. Désactivez-la pour améliorer la protection de la vie privée.',
    'Year' => 'Année',
    'Years' => 'Années',
    'You cannot invite participants!' => 'Vous ne pouvez pas inviter de participant·es !',
    'You don\'t have permission to delete this event!' => 'Vous n\'avez pas les permissions pour effacer cet événement.',
    'You have an <strong>{type}</strong> coming up' => 'Un événement de type <strong>{type}</strong> arrive bientôt',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Un événement de type <strong>{type}</strong> arrive bientôt : {title}',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => 'Vous êtes inscrit·e à l’événement « {contentTitle} » dans l’espace {spaceName} commençant à {time}.',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => 'Vous êtes inscrit·e à l’événement « {contentTitle} » commençant à {time}.',
    'You have been registered for the event "{contentTitle}".' => 'Vous êtes inscrit·e à l’événement « {contentTitle} ».',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Vos paramètres de rappels pour l\'évènement : <strong>\'{title}\'</strong>',
    'canceled' => 'annulé',
    'disabled' => 'désactivé',
    'first' => 'premier',
    'forth' => 'quatrième',
    'global' => 'global',
    'iCal' => 'iCal',
    'in seconds. 0 for no JWT token expiration.' => 'en secondes. 0 pour aucun délai d’expiration du jeton JWT.',
    'last' => 'dernier',
    'on weekdays' => 'les',
    'second' => 'deuxième',
    'third' => 'troisième',
    '{displayName} Birthday' => 'Anniversaire de {displayName}',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} vous a ajouté à l\'événement « {contentTitle} » dans l\'espace {spaceName} et qui débute à {time}.',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} vient de vous ajouter à l’événement « {contentTitle} ».',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} vient de vous inviter à l’événement « {contentTitle} » dans l’espace {spaceName} ; l’événement commence à {time}.',
    '{displayName} invited you to the event "{contentTitle}".' => '{displayName} vient de vous inviter à l’événement « {contentTitle} ».',
    '{name} Calendar' => 'Calendrier {name}',
    'Filter' => '',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
    <strong>Set reminder</strong> link.' => '',
];
